clear
clc
close all

%% READ DATA
DATA=load('result.out'); 
PARAMETERS=load('parameters.dat');
GEOMETRY=load('geometry.dat');

Nd=size(DATA,1);   %number of data
Np=DATA(Nd,2)+1;   %number of pedestrians
Nt=DATA(Nd,1)+1;   %number of time step
Dt=PARAMETERS(2);  %time step
contactdist=PARAMETERS(6);
physicaldist=PARAMETERS(8);

% rows:agents, columns:time
POSx=reshape(DATA(:,3),[Np,Nt]);     %position (x)
POSy=reshape(DATA(:,4),[Np,Nt]);     %position (y)

ISCONTACTED=reshape(DATA(:,5),[Np,Nt]);
ISPUSHED=reshape(DATA(:,6),[Np,Nt]);
DESIREDDISTANCE=reshape(DATA(:,7),[Np,Nt]);

L=GEOMETRY(1);  %corridor length
H=GEOMETRY(3);  %corridor height


%% PLOT
figure(1)
%set(gcf, 'Position', 1*[10, 200, 1300, floor(1300/3)])
axis([-1 L+1 -1 H+1])
pbaspect([(L+1)/(H+1) 1 1]);
ax=gca;
ax.FontSize=6; 
hold on;
 
for n=1:1:Nt 
  
  cla

  %geometry
  plot([0 L],[0 0],'k','LineWidth',2')
  plot([0 L],[H H],'k','LineWidth',2')
  plot([L L],[0 H],'r','LineWidth',2') %gate 

  %normal agent
  temp=( (ISCONTACTED(:,n)==0) & (ISPUSHED(:,n)==0) );
  X=POSx(temp,n);
  Y=POSy(temp,n);
  centers=[X Y];
  radii_in=0.5*physicaldist*ones(length(X),1);
  radii_out=0.5*contactdist*ones(length(X),1);
  viscircles(centers,radii_in,'Color','b','LineWidth',1');
  viscircles(centers,radii_out,'Color','b');
      
  %contacted agents
  temp=( (ISCONTACTED(:,n)==1) & (ISPUSHED(:,n)==0) );
  X=POSx(temp,n);
  Y=POSy(temp,n);
  centers=[X Y];
  radii_in=0.5*physicaldist*ones(length(X),1);
  viscircles(centers,radii_in,'Color','g');
  
  %pushed agents
  temp=(ISPUSHED(:,n)==1);
  X=POSx(temp,n);
  Y=POSy(temp,n);
  centers=[X Y];
  radii_in=0.5*physicaldist*ones(length(X),1);
  viscircles(centers,radii_in,'Color','r');
  
  xlabel(['n=' num2str(n)] ,'FontSize',10);
  pause(0.1);

end